<?php

namespace WPFormsDrip;

use WPFormsDrip\Provider\Core;
use WPForms\Providers\Providers;

/**
 * Class Plugin that loads the plugin.
 *
 * @since 1.0.0
 */
class Plugin {

	/**
	 * Get a single instance of the plugin.
	 *
	 * @since 1.0.0
	 *
	 * @return Plugin
	 */
	public static function get_instance() {

		static $instance;

		if ( ! $instance ) {
			$instance = new Plugin();
		}

		return $instance;
	}

	/**
	 * Plugin constructor.
	 *
	 * @since 1.0.0
	 */
	public function __construct() {

		$providers_loader = Providers::get_instance();

		$providers_loader->register(
			Core::get_instance()
		);
	}

	/**
	 * Sanitize custom field identifier according to Drip specification.
	 *
	 * @see https://help.drip.com/hc/en-us/articles/115003767652-Custom-Fields
	 *
	 * @since 1.4.0
	 *
	 * @param string $str Custom field id.
	 *
	 * @return string Sanitized custom field id.
	 */
	public function sanitize_field_id( $str ) {

		$str = preg_replace( '/[ +-<>]/', '_', $str );
		$str = preg_replace( '/[^0-9a-z_]/i', '', $str );

		return $str;
	}
}
