/* global SignupEmbedder, WPFormsBuilder, SignupEmbedderOptions, wpformsHubSpotPopupVars */
'use strict';

/**
 * WPForms HubSpot Popup.
 *
 * @since 1.0.0
 */
var WPFormsHubSpotPopup = window.WPFormsHubSpotPopup || ( function( document, window, $ ) {

	/**
	 * Public functions and properties.
	 *
	 * @since 1.0.0
	 *
	 * @type {object}
	 */
	var app = {

		/**
		 * Start the engine.
		 *
		 * @since 1.0.0
		 */
		init: function() {

			$( app.ready );
		},

		/**
		 * Document ready.
		 *
		 * @since 1.0.0
		 */
		ready: function() {

			$( document ).on( 'click', '.wpforms-hubspot-auth', app.hubspotAuth );
		},

		/**
		 * Call HubSpot script.
		 *
		 * @since 1.0.0
		 */
		hubspotAuth: function() {

			if ( typeof SignupEmbedder !== 'function' ) {
				return;
			}

			new SignupEmbedder()
				.setFlow( 'integrations' )
				.addQueryParam( 'integration', 'wpforms' )
				.setOptions(
					new SignupEmbedderOptions()
						.setOAuth( wpformsHubSpotPopupVars.data.client_id, wpformsHubSpotPopupVars.data.scopes, wpformsHubSpotPopupVars.data.redirect_url )
						.setAffiliateLink( wpformsHubSpotPopupVars.data.affiliate_link )
				)
				.asPopup();

			window.addEventListener( 'message', ( event ) => {
				if (
					event.origin === new URL( wpformsHubSpotPopupVars.data.redirect_url ).origin &&
					event.data.code &&
					event.data.access_token
				) {

					if ( typeof WPFormsBuilder !== 'undefined' ) {
						WPFormsBuilder.setCloseConfirmation( false );
						WPFormsBuilder.showLoadingOverlay();
					} else {
						$.alert( {
							title  : '',
							content: wpformsHubSpotPopupVars.strings.alert,
							icon   : 'fa fa-info-circle',
							type   : 'blue',
							buttons: false,
						} );
					}

					jQuery.post(
						wpformsHubSpotPopupVars.ajax_url,
						{
							action: 'wpforms_hubspot_popup_oauth',
							data  : event.data,
							nonce : wpformsHubSpotPopupVars.nonce,
						},
						function() {

							location.reload();
						}
					);
				}
			} );
		},
	};

	// Provide access to public functions/properties.
	return app;

}( document, window, jQuery ) );

// Initialize.
WPFormsHubSpotPopup.init();
