<?php

namespace WPFormsHubspot\Provider\Actions;

use WPFormsHubspot\Api\Api;
use WPFormsHubspot\Provider\FieldMapper;

/**
 * Class Action.
 *
 * @since 1.0.0
 */
abstract class Action {

	/**
	 * Connection with the HubSpot API.
	 *
	 * @since 1.0.0
	 *
	 * @var Api
	 */
	protected $api;

	/**
	 * Field mapper.
	 *
	 * @since 1.0.0
	 *
	 * @var FieldMapper
	 */
	protected $field_mapper;

	/**
	 * Connection data.
	 *
	 * @since 1.0.0
	 *
	 * @var array
	 */
	protected $connection_data;

	/**
	 * Form data.
	 *
	 * @since 1.0.0
	 *
	 * @var array
	 */
	protected $form_data;

	/**
	 * Form fields.
	 *
	 * @since 1.0.0
	 *
	 * @var array
	 */
	protected $fields;

	/**
	 * Form submission page URL.
	 *
	 * @since 1.0.0
	 *
	 * @var string
	 */
	protected $page_url;

	/**
	 * Action constructor.
	 *
	 * @since 1.0.0
	 *
	 * @param Api         $api             HubSpot API.
	 * @param FieldMapper $field_mapper    Field mapper.
	 * @param array       $connection_data Connection data.
	 * @param array       $form_data       Form data.
	 * @param array       $fields          Form fields.
	 * @param string      $page_url        Form submission page URL.
	 */
	public function __construct( Api $api, FieldMapper $field_mapper, $connection_data, $form_data, $fields, $page_url ) {

		$this->api             = $api;
		$this->field_mapper    = $field_mapper;
		$this->connection_data = $connection_data;
		$this->form_data       = $form_data;
		$this->fields          = $fields;
		$this->page_url        = $page_url;
	}

	/**
	 * Run action.
	 *
	 * @since 1.0.0
	 *
	 * @return void
	 */
	abstract public function run();
}
