<?php

namespace WPFormsHubspot\Provider\Actions;

use WPFormsHubspot\Api\Exceptions\ResponseException;
use WPFormsHubspot\Api\Exceptions\RequiredArgumentMissingException;

/**
 * Class ContactAction.
 *
 * @since 1.0.0
 */
class ContactDeleteAction extends Action {

	/**
	 * Run action.
	 *
	 * @since 1.0.0
	 *
	 * @throws ResponseException                Invalid response.
	 * @throws RequiredArgumentMissingException Required argument is missing.
	 */
	public function run() {

		$email = sanitize_email( $this->field_mapper->get_field_value_by_id( $this->field_mapper->get_required_field_value( 'email', 'field_id' ) ) );

		if ( wpforms_is_empty_string( $email ) ) {
			throw new RequiredArgumentMissingException( 'email' );
		}

		$contact_response = $this->api->get_contact( $email );

		if ( $contact_response->has_errors() ) {
			throw new ResponseException( $contact_response->get_response_message() );
		}

		$contact_data = $contact_response->get_body();

		$response = $this->api->delete_contact( $contact_data['id'] );

		if ( $response->has_errors() ) {
			throw new ResponseException( $response->get_response_message() );
		}
	}
}
