<?php

namespace WPFormsHubspot\Provider;

/**
 * Class OAuthPopup.
 *
 * @since 1.0.0
 */
class OAuthPopup {

	/**
	 * APP scopes.
	 *
	 * @since 1.0.0
	 *
	 * @var string
	 */
	const APP_SCOPES = 'actions%20oauth%20forms%20crm.objects.contacts.read%20crm.objects.contacts.write%20crm.objects.companies.read%20crm.objects.companies.write%20crm.objects.owners.read%20crm.schemas.contacts.read%20crm.schemas.contacts.write%20crm.schemas.companies.read%20crm.schemas.companies.write';

	/**
	 * APP Client ID.
	 *
	 * @since 1.0.0
	 *
	 * @var string
	 */
	const APP_CLIENT_ID = 'c81b88ea-ecc1-4f1b-8e8e-fac72eee76c0';

	/**
	 * Add hooks.
	 *
	 * @since 1.0.0
	 */
	public function hooks() {

		add_action( 'wpforms_builder_enqueues', [ $this, 'enqueue_scripts' ] );
		add_action( 'wpforms_settings_enqueue', [ $this, 'enqueue_scripts' ] );
	}

	/**
	 * Load scripts.
	 *
	 * @since 1.0.0
	 */
	public function enqueue_scripts() {

		$min = wpforms_get_min_suffix();

		wp_enqueue_script( 'hubspot-embedder', 'https://js.hubspot.com/signup-ui-lego-embedder/embedder.js', [], WPFORMS_HUBSPOT_VERSION, true );

		wp_enqueue_script(
			'wpforms-hubspot-popup',
			WPFORMS_HUBSPOT_URL . "assets/js/hubspot-popup$min.js",
			[ 'jquery' ],
			WPFORMS_HUBSPOT_VERSION,
			true
		);

		wp_localize_script(
			'wpforms-hubspot-popup',
			'wpformsHubSpotPopupVars',
			[
				'data'     => $this->get_oauth_popup_data(),
				'ajax_url' => admin_url( 'admin-ajax.php' ),
				'nonce'    => wp_create_nonce( 'wpforms-hubspot' ),
				'strings'  => [
					'alert' => esc_html__( 'Please wait, your account is saving now.', 'wpforms-hubspot' ),
				],
			]
		);
	}

	/**
	 * Get APP data needed for oauth in sing-up popup.
	 *
	 * @since 1.0.0
	 *
	 * @return array
	 */
	private function get_oauth_popup_data() {

		return [
			'client_id'      => self::APP_CLIENT_ID,
			'scopes'         => self::APP_SCOPES,
			'redirect_url'   => wpforms_hubspot()->get( 'account' )->get_server_url(),
			'affiliate_link' => 'https://hubspot.sjv.io/jW50q0',
		];
	}
}
