<?php

namespace WPFormsMailerlite\Api;

/**
 * Create connection between addon and API.
 *
 * @since 1.0.0
 */
class Client {

	/**
	 * API key.
	 *
	 * @since 1.0.0
	 *
	 * @var string
	 */
	private $api_key;

	/**
	 * Create new connection to the API.
	 *
	 * @since 1.0.0
	 *
	 * @param string $api_key API key.
	 *
	 * @return Connection|null
	 */
	public function new_connection( $api_key ) {

		$this->api_key = $api_key;
		$class         = 'WPFormsMailerlite\Api\\' . $this->get_api_type();

		return class_exists( $class ) ? new Connection( new $class( $api_key ) ) : null;
	}

	/**
	 * Check to which API the ley belongs.
	 *
	 * @since 1.0.0
	 *
	 * @return string
	 */
	private function get_api_type() {

		return $this->is_valid_md5() ? 'MailerLiteAPI' : 'ConnectAPI';
	}

	/**
	 * Check API key for valid md5 hash.
	 *
	 * @since 1.0.0
	 *
	 * @return bool
	 */
	private function is_valid_md5() {

		return strlen( $this->api_key ) === 32 && ctype_xdigit( $this->api_key );
	}
}
