<?php

namespace WPFormsMailerlite\Api;

/**
 * Class Connection.
 *
 * @since 1.0.0
 *
 * @method get_account()
 * @method get_subscriber( string $email )
 * @method create_contact( string $email, array $groups, array $fields, string $type )
 * @method update_contact( string $email, array $properties )
 * @method delete_contact( string $id )
 * @method delete_contact_from_group( int $id, int $group_id )
 * @method get_groups( int $limit, int $offset = 0 )
 * @method set_group( string $email, int $group_id )
 * @method get_fields()
 * @method get_all_groups()
 */
class Connection {

	/**
	 * API.
	 *
	 * @since 1.0.0
	 *
	 * @var PlatformInterface
	 */
	private $api;

	/**
	 * Connection constructor.
	 *
	 * @since 1.0.0
	 *
	 * @param MailerLiteAPI|ConnectAPI $api API instance.
	 */
	public function __construct( $api ) {

		$this->api = $api;
	}

	/**
	 * Proxies all method calls to the certain API object.
	 *
	 * @since 1.0.0
	 *
	 * @param string $method     Method name.
	 * @param array  $parameters Array of arguments.
	 */
	public function __call( $method, $parameters ) {

		return call_user_func_array( [ $this->api, $method ], $parameters );
	}
}
