<?php

namespace WPFormsMailerlite\Api;

use WPFormsMailerlite\Api\Http\Response;

/**
 * Interface PlatformInterface defines required methods for API communication classes to work.
 *
 * @since 1.0.0
 */
interface PlatformInterface {

	/**
	 * Retrieve an account information.
	 *
	 * @since 1.0.0
	 *
	 * @return Response
	 */
	public function get_account();

	/**
	 * Get contact by email.
	 *
	 * @since 1.0.0
	 *
	 * @param string $email Email.
	 *
	 * @return Response
	 */
	public function get_subscriber( $email );

	/**
	 * Create contact.
	 *
	 * @since 1.0.0
	 *
	 * @param string $email  Email.
	 * @param array  $groups Group.
	 * @param array  $fields Fields.
	 * @param string $type   Type.
	 *
	 * @return Response
	 */
	public function create_contact( $email, $groups, $fields, $type );

	/**
	 * Updating contact.
	 *
	 * @since 1.0.0
	 *
	 * @param string $email      Existing contact email.
	 * @param array  $properties Properties.
	 *
	 * @return Response
	 */
	public function update_contact( $email, $properties );

	/**
	 * Delete contact.
	 *
	 * @since 1.0.0
	 *
	 * @param string $id Contact ID.
	 *
	 * @return Response
	 */
	public function delete_contact( $id );

	/**
	 * Delete contact from a group.
	 *
	 * @since 1.0.0
	 *
	 * @param int $id       Contact ID.
	 * @param int $group_id Group ID.
	 *
	 * @return Response
	 */
	public function delete_contact_from_group( $id, $group_id );

	/**
	 * Get a list of groups.
	 *
	 * @since 1.0.0
	 *
	 * @param int $limit  Limit of records.
	 * @param int $offset Offset for lists select.
	 *
	 * @return Response
	 */
	public function get_groups( $limit, $offset );

	/**
	 * Get all groups.
	 *
	 * @since 1.0.0
	 *
	 * @return array
	 */
	public function get_all_groups();

	/**
	 * Get list of custom fields.
	 *
	 * @since 1.0.0
	 */
	public function get_fields();
}
