<?php

namespace WPFormsMailerlite\Provider\Actions;

use WPFormsMailerlite\Api\Exceptions\ResponseException;
use WPFormsMailerlite\Api\Exceptions\RequiredArgumentMissingException;

/**
 * Class UnsubscribeAction.
 *
 * @since 1.0.0
 */
class UnsubscribeAction extends Action {

	/**
	 * Run action.
	 *
	 * @since 1.0.0
	 *
	 * @throws ResponseException Invalid response.
	 * @throws RequiredArgumentMissingException Required argument is missing.
	 * phpcs:ignore Squiz.Commenting.FunctionCommentThrowTag.WrongNumber
	 */
	public function run() {

		$email   = $this->field_mapper->get_field_value_by_id( $this->field_mapper->get_required_field_value( 'email', 'field_id' ) );
		$contact = $this->connection->get_subscriber( $email );
		$groups  = $this->field_mapper->get_group_field_value( 'groups', 'group_id' );

		if ( empty( $groups ) ) {
			throw new RequiredArgumentMissingException( 'groups' );
		}

		if ( $contact->has_errors() ) {
			throw new ResponseException( $contact->get_response_message() );
		}

		$contact = $contact->get_data();

		if ( empty( $contact['id'] ) ) {
			return;
		}

		foreach ( $groups as $group ) {
			$this->connection->delete_contact_from_group( $contact['id'], $group );
		}
	}
}
