<?php

namespace WPFormsMailerlite\Provider\Settings;

use Exception;
use WPFormsMailerlite\Plugin;
use WPFormsMailerlite\Api\Exceptions\RequiredArgumentMissingException;
use WPForms\Providers\Provider\Settings\PageIntegrations as PageIntegrationsAbstract;

/**
 * Class PageIntegrations handles functionality on the Settings > Integrations page.
 *
 * @since 1.0.0
 */
class PageIntegrations extends PageIntegrationsAbstract {

	/**
	 * AJAX to add a provider from the settings integrations tab.
	 *
	 * @since 1.0.0
	 *
	 * phpcs:ignore Squiz.Commenting.FunctionCommentThrowTag.Missing
	 */
	public function ajax_connect() { // phpcs:ignore Generic.Metrics.CyclomaticComplexity.TooHigh

		parent::ajax_connect();

		$data         = wp_unslash( wp_parse_args( $_POST['data'] ) ); // phpcs:ignore
		$api_key      = ! empty( $data['api_key'] ) ? sanitize_text_field( $data['api_key'] ) : '';
		$account_name = ! empty( $data['account_name'] ) ? sanitize_text_field( $data['account_name'] ) : '';

		try {
			if ( empty( $api_key ) ) {
				throw new RequiredArgumentMissingException( 'MailerLite API Key Field' );
			}

			$account = wpforms_mailerlite()
				->get( 'account' )
				->add( $api_key, $account_name );

			wp_send_json_success(
				[
					'html' => wpforms_mailerlite()
						->get( 'template' )
						->get_settings_template(
							'account-connected',
							[
								'label'     => ! empty( $account['label'] ) ? esc_html( $account['label'] ) : '',
								'core_slug' => esc_html( Plugin::SLUG ),
								'key'       => ! empty( $account['key'] ) ? esc_html( $account['key'] ) : '',
							]
						),
				]
			);
		} catch ( Exception $e ) {
			wp_send_json_error( [ 'error_msg' => esc_html( $e->getMessage() ) ] );
		}
	}

	/**
	 * Display fields that will store MailerLite account details.
	 *
	 * @since 1.0.0
	 */
	protected function display_add_new_connection_fields() {

		// phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
		echo wpforms_mailerlite()
			->get( 'template' )
			->get_settings_template(
				'new-account-form',
				[
					'core_name' => esc_html__( 'MailerLite', 'wpforms-mailerlite' ),
				]
			);
	}
}
