<?php
/**
 * Translatable provider name.
 *
 * @var string $core_name Integration name.
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

$api_key_placeholder = sprintf( /* translators: %s - current provider name. */
	__( '%s API Key *', 'wpforms-mailerlite' ),
	$core_name
);

$account_name_placeholder = sprintf( /* translators: %s - current provider name. */
	__( '%s Account Nickname', 'wpforms-mailerlite' ),
	$core_name
);

// Set UTM medium based on whether or not we are in the builder. wpforms_is_admin_page() returns false if we are in the builder.
$learn_more_utm_medium = wpforms_is_admin_page() ? 'Settings - Integration' : 'Marketing Integrations';

?>
<p>
	<input type="text" name="api_key" class="wpforms-required" placeholder="<?php echo esc_attr( $api_key_placeholder ); ?>">
	<span class="error" style="display: none;"></span>
</p>
<p>
	<input type="text" name="account_name" placeholder="<?php echo esc_attr( $account_name_placeholder ); ?>">
</p>
<p class="description">
	<?php
	printf(
		wp_kses( /* translators: %s - URL to the MilerLite Getting started page. */
			__( 'The API Key can be found in your MailerLite account settings. <a href="%s" target="_blank" rel="noopener noreferrer">Learn More</a>.', 'wpforms-mailerlite' ),
			[
				'a' => [
					'href'   => [],
					'target' => [],
					'rel'    => [],
				],
			]
		),
		esc_url( wpforms_utm_link( 'https://wpforms.com/docs/install-use-mailerlite-addon-wpforms', $learn_more_utm_medium, 'MailerLite Documentation' ) )
	);
	?>
</p>

<p class="error form-error" style="display: none">
	<?php esc_html_e( 'Something went wrong while performing an AJAX request.', 'wpforms-mailerlite' ); ?>
</p>
