<?php

namespace WPFormsSendinblue\Provider\Actions;

use WPFormsSendinblue\Api\Connection;
use WPFormsSendinblue\Provider\CustomFields\FieldMapper;

/**
 * Class Action.
 *
 * @since 1.0.0
 */
abstract class Action {

	/**
	 * Connection with the Sendinblue API.
	 *
	 * @since 1.0.0
	 *
	 * @var Connection
	 */
	protected $connection;

	/**
	 * Field mapper.
	 *
	 * @since 1.0.0
	 *
	 * @var FieldMapper
	 */
	protected $field_mapper;

	/**
	 * Connection data.
	 *
	 * @since 1.0.0
	 *
	 * @var array
	 */
	protected $connection_data;

	/**
	 * Action constructor.
	 *
	 * @since 1.0.0
	 *
	 * @param Connection  $connection      Sendinblue API Connection.
	 * @param FieldMapper $field_mapper    Field mapper.
	 * @param array       $connection_data Connection data.
	 */
	public function __construct( Connection $connection, FieldMapper $field_mapper, $connection_data ) {

		$this->connection      = $connection;
		$this->field_mapper    = $field_mapper;
		$this->connection_data = $connection_data;
	}

	/**
	 * Run action.
	 *
	 * @since 1.0.0
	 *
	 * @return void
	 */
	abstract public function run();
}
