<?php

namespace WPFormsSendinblue\Provider\Actions;

use WPFormsSendinblue\Api\Exceptions\ResponseException;
use WPFormsSendinblue\Api\Exceptions\RequiredArgumentMissingException;

/**
 * Class UnsubscribeAction.
 *
 * @since 1.0.0
 */
class UnsubscribeAction extends Action {

	/**
	 * Run action.
	 *
	 * @since 1.0.0
	 *
	 * @throws ResponseException Invalid response.
	 * @throws RequiredArgumentMissingException Required argument is missing.
	 */
	public function run() {

		$email = sanitize_email( $this->field_mapper->get_field_value_by_id( $this->field_mapper->get_required_field_value( 'email', 'field_id' ) ) );

		if ( ! $email ) {
			throw new RequiredArgumentMissingException( 'email' );
		}

		$list_id = absint( $this->field_mapper->get_required_field_value( 'list', 'list_id' ) );

		$response = $this->connection->delete_contact_from_list( $email, $list_id );

		if ( $response->has_errors() ) {
			throw new ResponseException( $response->get_response_message() );
		}
	}
}
