<?php

namespace WPFormsSendinblue\Provider\CustomFields;

/**
 * Class DefaultField.
 *
 * @since 1.0.0
 */
class DefaultField extends BaseField {

	/**
	 * Text format.
	 *
	 * @since 1.0.0
	 *
	 * @return string
	 */
	protected function text() {

		return (string) $this->field['value'];
	}

	/**
	 * Date format.
	 *
	 * @since 1.0.0
	 *
	 * @return string|null
	 */
	protected function date() {

		$time = strtotime( $this->field['value'] );

		return $time ? gmdate( 'Y-m-d', $time ) : null;
	}

	/**
	 * Number format.
	 *
	 * @since 1.0.0
	 *
	 * @return float|null
	 */
	protected function float() {

		return is_numeric( $this->field['value'] ) ? (float) $this->field['value'] : null;
	}

	/**
	 * Category format.
	 *
	 * @since 1.0.0
	 *
	 * @return null
	 */
	protected function category() {

		return null;
	}

	/**
	 * Boolean format.
	 *
	 * @since 1.0.0
	 *
	 * @return bool
	 */
	protected function boolean() {

		return ! empty( $this->field['value'] );
	}

	/**
	 * Phone format.
	 *
	 * @since 1.0.0
	 *
	 * @return string|null
	 */
	protected function phone() {

		return preg_replace( '/[^0-9]/', '' , $this->field['value'] );
	}
}
