<?php

namespace WPFormsSendinblue\Provider\CustomFields;

/**
 * Class RadioField.
 *
 * @since 1.0.0
 */
class RadioField extends DefaultField {

	/**
	 * Category format.
	 *
	 * @since 1.0.0
	 *
	 * @return int|null
	 */
	protected function category() {

		if ( empty( $this->attribute['enumeration'] ) ) {
			return null;
		}

		$value = $this->get_index_by_category_name();

		if ( $value ) {
			return $value;
		}

		return $this->get_selected_index();
	}

	/**
	 * Trying to find the index of a category by comparing the category name and value field.
	 *
	 * @since 1.0.0
	 *
	 * @return int|null
	 */
	private function get_index_by_category_name() {

		// Try to find element by label.
		foreach ( $this->attribute['enumeration'] as $choice ) {
			if ( ! isset( $choice['label'] ) || ! isset( $choice['value'] ) ) {
				continue;
			}

			if ( $choice['label'] === $this->field['value'] ) {
				return $choice['value'];
			}
		}

		return null;
	}

	/**
	 * Get index of selected choice.
	 *
	 * @since 1.0.0
	 *
	 * @return int|null
	 */
	private function get_selected_index() {

		if ( empty( $this->settings['choices'] ) || ! is_array( $this->settings['choices'] ) ) {
			return null;
		}

		$max_index = count( $this->attribute['enumeration'] ) - 1;

		// Get current element ID.
		foreach ( $this->settings['choices'] as $key => $choice ) {
			if ( isset( $choice['label'] ) && $this->field['value'] === $choice['label'] ) {
				return $key <= $max_index ? $key : null;
			}
		}

		return null;
	}
}
