<?php

namespace WPFormsSquare\Admin;

use WPFormsSquare\Helpers;
use WPFormsSquare\Connection;

/**
 * Integration with Block Editor.
 *
 * @since 1.4.0
 */
class BlockEditor {

	/**
	 * Handle name for wp_register_styles handle.
	 *
	 * @since 1.4.0
	 *
	 * @var string
	 */
	const HANDLE = 'wpforms-square-card-placeholder';

	/**
	 * Initialize.
	 *
	 * @since 1.4.0
	 */
	public function init() {

		$this->hooks();
	}

	/**
	 * Register hooks.
	 *
	 * @since 1.4.0
	 */
	public function hooks() {

		// Field styles for Gutenberg.
		add_action( 'enqueue_block_editor_assets', [ $this, 'enqueue_assets' ] );

		// Set editor style for block type editor. Must run at 20 in add-ons.
		add_filter( 'register_block_type_args', [ $this, 'register_block_type_args' ], 20, 2 );
	}

	/**
	 * Enqueue assets.
	 *
	 * @since 1.4.0
	 */
	public function enqueue_assets() {

		$min = wpforms_get_min_suffix();

		// Include styles if the "Include Form Styling > No Styles" is not set.
		if ( wpforms_setting( 'disable-css', '1' ) !== '3' ) {
			wp_enqueue_style(
				'wpforms-square',
				WPFORMS_SQUARE_URL . "assets/css/wpforms-square{$min}.css",
				[],
				WPFORMS_SQUARE_VERSION
			);

			wp_enqueue_style(
				self::HANDLE,
				WPFORMS_SQUARE_URL . "assets/css/wpforms-square-card-placeholder{$min}.css",
				[],
				WPFORMS_SQUARE_VERSION
			);
		}

		wp_enqueue_script(
			'square-web-payments-sdk',
			Helpers::is_sandbox_mode() ? 'https://sandbox.web.squarecdn.com/v1/square.js' : 'https://web.squarecdn.com/v1/square.js',
			[],
			null,
			true
		);

		wp_enqueue_script(
			'wpforms-square',
			WPFORMS_SQUARE_URL . "assets/js/wpforms-square{$min}.js",
			[ 'jquery', 'square-web-payments-sdk' ],
			WPFORMS_SQUARE_VERSION,
			true
		);

		/** This filter is documented in src/Frontend.php */
		$card_config = (array) apply_filters( 'wpforms_square_frontend_enqueues_card_config', [], [] ); // phpcs:ignore WPForms.PHP.ValidateHooks.InvalidHookName
		$connection  = Connection::get();

		wp_localize_script(
			'wpforms-square',
			'wpforms_square',
			[
				'client_id'   => $connection instanceof Connection ? $connection->get_client_id() : 0,
				'location_id' => Helpers::get_location_id(),
				'card_config' => $card_config,
				'i18n'        => [
					'card_init_error' => esc_html__( 'Initializing Card failed.', 'wpforms-square' ),
				],
			]
		);
	}

	/**
	 * Set editor style for block type editor.
	 *
	 * @since 1.4.0
	 *
	 * @param array  $args       Array of arguments for registering a block type.
	 * @param string $block_type Block type name including namespace.
	 */
	public function register_block_type_args( $args, $block_type ) {

		if ( $block_type !== 'wpforms/form-selector' ) {
			return $args;
		}

		$min = wpforms_get_min_suffix();

		// CSS.
		wp_register_style(
			self::HANDLE,
			WPFORMS_SQUARE_URL . "assets/css/wpforms-square-card-placeholder{$min}.css",
			[ $args['editor_style'] ],
			WPFORMS_SQUARE_VERSION
		);

		$args['editor_style'] = self::HANDLE;

		return $args;
	}
}
